## Team awareness

Other agents are working in parallel. Recent activity:
{{ BULLETIN_SUMMARY }}

If you need to create a shared utility, check if it already exists first.
If you define an API endpoint, use consistent naming with existing endpoints.
